<?php

namespace App\Notifications\Admin;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class NewJobAvailableNotification extends Notification implements ShouldQueue
{
    use Queueable;

    /**
     * Create a new notification instance.
     *
     * @return void
     */
    public $admin, $job;

    public function __construct($admin, $job)
    {
        $this->admin = $admin;
        $this->job = $job;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        return ['mail', 'database'];
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        $type = "new_job_available";
        $formatted_mail_data = getFormattedTextByType($type, [
            "admin_name" => $this->admin->name
        ]);
        $subject = $formatted_mail_data["subject"];
        $message = $formatted_mail_data["message"];

        return (new MailMessage)
            ->subject($subject)
            ->line($message)
            ->action('Visit Job', route('job.index', ['title' => $this->job->title]))
            ->view("mails.email-template", ["content" => $message]);
    }

    /**
     * Get the array representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function toArray($notifiable)
    {
        return [
            'title' => 'A new job is available for approval',
            'url' => route('job.index', ['title' => $this->job->title]),
        ];
    }
}
